@@ -21,6 +21,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -45,6 +46,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -79,6 +81,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -120,6 +123,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -139,6 +143,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -175,6 +180,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -211,6 +217,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
@@ -241,6 +248,27 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
         )
         self.assertTrue(broadband_isp_info["keep_phone_number"])
 
+    def test_broadband_contract_portability_previous_service_fibre(self):
+        contract_data = FakeContractForm().data
+
+        contract_data["service"] = "adsl"
+        contract_data["internet_now"] = "fibre"
+        contract_data["internet_phone_number"] = "current_number"
+        contract_data["internet_telecom_company"] = "4"
+
+        subscription_request_id = 123
+
+        sr_data = CRMLeadFromContractForm(
+            contract_data,
+            {},
+            subscription_request_id=subscription_request_id,
+        ).to_dict()
+
+        lead_line = sr_data["lead_line_ids"][0]
+        broadband_isp_info = lead_line["broadband_isp_info"]
+
+        self.assertEqual(broadband_isp_info["previous_service"], "fiber")
+
     def test_two_services(self):
         contract_data = FakeContractForm().data
 
@@ -255,6 +283,7 @@ class CRMLeadFromContractFormTests(unittest.TestCase):
 
         sr_data = CRMLeadFromContractForm(
             contract_data,
+            {},
             subscription_request_id=subscription_request_id,
         ).to_dict()
 
